==> ogPypeline-0.1.0.tar.gz: ogPypeline-0.1.0/README.md <==
# ogPypeline

A python package for the oil and gas industry. Initial release is focused on 64 useful unit conversions across multiple disciplines.
Developed by Tim Clarke (c) 2021

## Installation

You can install ogPypeline from [PyPI](https://pypi.org/project/ogPypeline/):

    pip install ogPypeline

## Documentation

Docs are available at <https://ogpypelines.readthedocs.io/en/latest/index.html>

## Reporting Issues
To report bugs, errors or make a suggestion suggestions, click on the issues tab at the top of the repo and create a new case.

## License
Copyright 2021 Timothy Clarke

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> ogPypeline-0.1.5.tar.gz: ogPypeline-0.1.5/README.md <==
# ogPypeline

A python package for the oil and gas industry. Initial release is focused on 64 useful unit conversions across multiple disciplines.
Developed by Tim Clarke (c) 2021

## Installation

You can install ogPypeline from [PyPI](https://pypi.org/project/ogPypeline/):

    pip install ogPypeline

## Documentation

Docs are available at [ReadTheDocs](https://ogpypeline.readthedocs.io/en/latest/index.html) 

## Reporting Issues
To report bugs, errors or make a suggestion suggestions, click on the issues tab at the top of the repo and create a new case.

## License
Copyright 2021 Timothy Clarke

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
